Files bundle — Invenio 3.4.0a8 documentation

# Files bundle

The files bundle contains all modules related to files management, an object storage REST API, storage backends, file previewers, IIIF image APIs and an integration layer between files and records.

Included modules:

- invenio-files-rest

    - Object storage REST API for Invenio with many supported backend storage protocols and file integrity checking.

- invenio-iiif

    - International Image Interoperability Framework (IIIF) server for making thumbnails and zooming images.

- invenio-previewer

    - Previewer for Markdown, JSON/XML, CSV, PDF, JPEG, PNG, TIFF, GIF and ZIP files.

- invenio-records-files

    - Integration layer between object storage and records.